EXPORTS
	??1CNotifyReadPropPipe@@UAE@XZ @ 1 NONAME ; CNotifyReadPropPipe::~CNotifyReadPropPipe(void)
	??1CPosServerWatcher@@UAE@XZ @ 2 NONAME ; CPosServerWatcher::~CPosServerWatcher(void)
	??1CPropPipeBase@@UAE@XZ @ 3 NONAME ; CPropPipeBase::~CPropPipeBase(void)
	??1CReadPropPipe@@UAE@XZ @ 4 NONAME ; CReadPropPipe::~CReadPropPipe(void)
	??1CWritePropPipe@@UAE@XZ @ 5 NONAME ; CWritePropPipe::~CWritePropPipe(void)
	??5CReadPropPipe@@QAEAAV0@AAJ@Z @ 6 NONAME ; class CReadPropPipe & CReadPropPipe::operator>>(long &)
	??5CReadPropPipe@@QAEAAV0@AAVTDes16@@@Z @ 7 NONAME ; class CReadPropPipe & CReadPropPipe::operator>>(class TDes16 &)
	??5CReadPropPipe@@QAEAAV0@AAVTDes8@@@Z @ 8 NONAME ; class CReadPropPipe & CReadPropPipe::operator>>(class TDes8 &)
	??6CWritePropPipe@@QAEAAV0@ABJ@Z @ 9 NONAME ; class CWritePropPipe & CWritePropPipe::operator<<(long const &)
	??6CWritePropPipe@@QAEAAV0@ABVTDesC16@@@Z @ 10 NONAME ; class CWritePropPipe & CWritePropPipe::operator<<(class TDesC16 const &)
	??6CWritePropPipe@@QAEAAV0@ABVTDesC8@@@Z @ 11 NONAME ; class CWritePropPipe & CWritePropPipe::operator<<(class TDesC8 const &)
	?CancelRequest@CPosServerWatcher@@QAEXXZ @ 12 NONAME ; void CPosServerWatcher::CancelRequest(void)
	?CommitL@CWritePropPipe@@QAEXJ@Z @ 13 NONAME ; void CWritePropPipe::CommitL(long)
	?CompleteRequest@CPosServerWatcher@@QAEXXZ @ 14 NONAME ; void CPosServerWatcher::CompleteRequest(void)
	?Flush@LBSParamLogger@@SAXXZ @ 15 NONAME ; void LBSParamLogger::Flush(void)
	?HexDump@LbsTestLogger@@SAXW4TLbsTestLogPriority@@PBEH@Z @ 16 NONAME ; void LbsTestLogger::HexDump(enum TLbsTestLogPriority, unsigned char const *, int)
	?Initialize@LbsTestLogger@@SAXXZ @ 17 NONAME ; void LbsTestLogger::Initialize(void)
	?IssueGetLastKnownPosition@CPosServerWatcher@@QAEXXZ @ 18 NONAME ; void CPosServerWatcher::IssueGetLastKnownPosition(void)
	?IssueNotifyPositionUpdate@CPosServerWatcher@@QAEXXZ @ 19 NONAME ; void CPosServerWatcher::IssueNotifyPositionUpdate(void)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVRLbsAssistanceDataBuilderSet@@@Z @ 20 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class RLbsAssistanceDataBuilderSet const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTDesC16@@@Z @ 21 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TDesC16 const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsExternalRequestInfo@@@Z @ 22 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsExternalRequestInfo const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsGpsOptions@@@Z @ 23 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsGpsOptions const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsLocRequestQuality@@@Z @ 24 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsLocRequestQuality const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsNetPosCapabilities@@@Z @ 25 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsNetPosCapabilities const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsNetPosMethod@@@Z @ 26 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsNetPosMethod const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsNetPosRequestMethod@@@Z @ 27 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsNetPosRequestMethod const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsNetPosRequestOptionsBase@@@Z @ 28 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsNetPosRequestOptionsBase const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsNetPosRequestPrivacy@@@Z @ 29 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsNetPosRequestPrivacy const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsNetPosRequestQuality@@@Z @ 30 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsNetPosRequestQuality const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsNetSessionId@@@Z @ 31 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsNetSessionId const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTLbsTransmitPositionOptions@@@Z @ 32 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TLbsTransmitPositionOptions const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTPositionInfoBase@@@Z @ 33 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TPositionInfoBase const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@ABVTTime@@@Z @ 34 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, class TTime const &)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@H@Z @ 35 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, int)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@J@Z @ 36 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, long)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@K@Z @ 37 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, unsigned long)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@W4TLbsNetProtocolService@MLbsNetworkProtocolObserver@@@Z @ 38 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, enum MLbsNetworkProtocolObserver::TLbsNetProtocolService)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@W4TLbsPrivacyResponse@CLbsNetworkProtocolBase@@@Z @ 39 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, enum CLbsNetworkProtocolBase::TLbsPrivacyResponse)
	?Log@LBSParamLogger@@SAXABVTPtrC16@@W4TLbsSystemStatus@CLbsNetworkProtocolBase@@@Z @ 40 NONAME ; void LBSParamLogger::Log(class TPtrC16 const &, enum CLbsNetworkProtocolBase::TLbsSystemStatus)
	?Method@LBSParamLogger@@SAXABVTPtrC16@@0@Z @ 41 NONAME ; void LBSParamLogger::Method(class TPtrC16 const &, class TPtrC16 const &)
	?NewL@CNotifyReadPropPipe@@SAPAV1@KKAAVMReadPropPipeObserver@@@Z @ 42 NONAME ; class CNotifyReadPropPipe * CNotifyReadPropPipe::NewL(unsigned long, unsigned long, class MReadPropPipeObserver &)
	?NewL@CReadPropPipe@@SAPAV1@KK@Z @ 43 NONAME ; class CReadPropPipe * CReadPropPipe::NewL(unsigned long, unsigned long)
	?NewL@CWritePropPipe@@SAPAV1@KK@Z @ 44 NONAME ; class CWritePropPipe * CWritePropPipe::NewL(unsigned long, unsigned long)
	?NewLC@CPosServerWatcher@@SAPAV1@AAVRPositioner@@AAVMPosServerObserver@@@Z @ 45 NONAME ; class CPosServerWatcher * CPosServerWatcher::NewLC(class RPositioner &, class MPosServerObserver &)
	?OverWrite@LbsTestLogger@@SAXABVTDesC16@@@Z @ 46 NONAME ; void LbsTestLogger::OverWrite(class TDesC16 const &)
	?OverWrite@LbsTestLogger@@SAXABVTDesC8@@@Z @ 47 NONAME ; void LbsTestLogger::OverWrite(class TDesC8 const &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAH@Z @ 48 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, int &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAK@Z @ 49 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, unsigned long &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVHBufC16@@@Z @ 50 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class HBufC16 * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVRLbsAssistanceDataBuilderSet@@@Z @ 51 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class RLbsAssistanceDataBuilderSet * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsExternalRequestInfo@@@Z @ 52 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsExternalRequestInfo * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosCapabilities@@@Z @ 53 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosCapabilities * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosMethod@@@Z @ 54 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosMethod * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestMethod@@@Z @ 55 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestMethod * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestOptionsBase@@@Z @ 56 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestOptionsBase * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestPrivacy@@@Z @ 57 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestPrivacy * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestQuality@@@Z @ 58 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestQuality * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetSessionId@@@Z @ 59 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetSessionId * &)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTPositionInfoBase@@@Z @ 60 NONAME ABSENT ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TPositionInfoBase * &)
	?RefreshL@CReadPropPipe@@QAEXJ@Z @ 61 NONAME ; void CReadPropPipe::RefreshL(long)
	?ResetL@CWritePropPipe@@QAEXXZ @ 62 NONAME ; void CWritePropPipe::ResetL(void)
	?Write@LbsTestLogger@@SAXW4TLbsTestLogType@@W4TLbsTestLogPriority@@V?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 63 NONAME ; void LbsTestLogger::Write(enum TLbsTestLogType, enum TLbsTestLogPriority, class TRefByValue<class TDesC16 const >, ...)
	?Write@LbsTestLogger@@SAXW4TLbsTestLogType@@W4TLbsTestLogPriority@@V?$TRefByValue@$$CBVTDesC8@@@@ZZ @ 64 NONAME ; void LbsTestLogger::Write(enum TLbsTestLogType, enum TLbsTestLogPriority, class TRefByValue<class TDesC8 const >, ...)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@AAVRLbsAssistanceDataBuilderSet@@@Z @ 65 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class RLbsAssistanceDataBuilderSet &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABH@Z @ 66 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, int const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABK@Z @ 67 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, unsigned long const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTDesC16@@@Z @ 68 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TDesC16 const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsExternalRequestInfo@@@Z @ 69 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsExternalRequestInfo const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsNetPosCapabilities@@@Z @ 70 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsNetPosCapabilities const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsNetPosMethod@@@Z @ 71 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsNetPosMethod const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsNetPosRequestMethod@@@Z @ 72 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsNetPosRequestMethod const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsNetPosRequestOptionsBase@@@Z @ 73 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsNetPosRequestOptionsBase const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsNetPosRequestPrivacy@@@Z @ 74 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsNetPosRequestPrivacy const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsNetPosRequestQuality@@@Z @ 75 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsNetPosRequestQuality const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTLbsNetSessionId@@@Z @ 76 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TLbsNetSessionId const &)
	?WriteL@LBSTestMarshaller@@SAXAAVCWritePropPipe@@ABVTPositionInfoBase@@@Z @ 77 NONAME ; void LBSTestMarshaller::WriteL(class CWritePropPipe &, class TPositionInfoBase const &)
	??1CTransmitServerWatcher@@UAE@XZ @ 78 NONAME ; CTransmitServerWatcher::~CTransmitServerWatcher(void)
	?CancelTransmit@CTransmitServerWatcher@@QAEXXZ @ 79 NONAME ; void CTransmitServerWatcher::CancelTransmit(void)
	?IssueTransmitPosition@CTransmitServerWatcher@@QAEXABVTDesC16@@I@Z @ 80 NONAME ; void CTransmitServerWatcher::IssueTransmitPosition(class TDesC16 const &, unsigned int)
	?NewLC@CTransmitServerWatcher@@SAPAV1@AAVRLbsTransmitPosition@@PAVMTransmitServerObserver@@@Z @ 81 NONAME ; class CTransmitServerWatcher * CTransmitServerWatcher::NewLC(class RLbsTransmitPosition &, class MTransmitServerObserver *)
	?RefreshL@CReadPropPipe@@QAEXJAAVTRequestStatus@@@Z @ 82 NONAME ; void CReadPropPipe::RefreshL(long, class TRequestStatus &)
	?CancelRefresh@CReadPropPipe@@QAEXXZ @ 83 NONAME ; void CReadPropPipe::CancelRefresh(void)
	?CommitAndWaitL@CWritePropPipe@@QAEXJ@Z @ 84 NONAME ; void CWritePropPipe::CommitAndWaitL(long)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsExternalRequestInfo@@PAVCMemoryManager@@@Z @ 85 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsExternalRequestInfo * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestPrivacy@@PAVCMemoryManager@@@Z @ 86 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestPrivacy * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetSessionId@@PAVCMemoryManager@@@Z @ 87 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetSessionId * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosCapabilities@@PAVCMemoryManager@@@Z @ 88 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosCapabilities * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosMethod@@PAVCMemoryManager@@@Z @ 89 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosMethod * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestQuality@@PAVCMemoryManager@@@Z @ 90 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestQuality * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestMethod@@PAVCMemoryManager@@@Z @ 91 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestMethod * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTLbsNetPosRequestOptionsBase@@PAVCMemoryManager@@@Z @ 92 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TLbsNetPosRequestOptionsBase * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVTPositionInfoBase@@PAVCMemoryManager@@@Z @ 93 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class TPositionInfoBase * &, class CMemoryManager *)
	?ReadL@LBSTestMarshaller@@SAXAAVCReadPropPipe@@AAPAVRLbsAssistanceDataBuilderSet@@PAVCMemoryManager@@@Z @ 94 NONAME ; void LBSTestMarshaller::ReadL(class CReadPropPipe &, class RLbsAssistanceDataBuilderSet * &, class CMemoryManager *)

